==> seismic_rna-0.17.0-py3-none-any.whl: seismicrna/sim/main.py <==
from click import group

from . import clusts, ends, fastq, fold, muts, ref, relate, total
from ..core.arg import CMD_SIM


# Group for all sim commands
@group(CMD_SIM)
def cli():
    """ Simulate sequences, structures, and samples. """


# Add simulation commands to the CLI.
for module in (clusts, ends, fastq, fold, muts, ref, relate, total):
    cli.add_command(module.cli)

########################################################################
#                                                                      #
# © Copyright 2024, the Rouskin Lab.                                   #
#                                                                      #
# This file is part of SEISMIC-RNA.                                    #
#                                                                      #
# SEISMIC-RNA is free software; you can redistribute it and/or modify  #
# it under the terms of the GNU General Public License as published by #
# the Free Software Foundation; either version 3 of the License, or    #
# (at your option) any later version.                                  #
#                                                                      #
# SEISMIC-RNA is distributed in the hope that it will be useful, but   #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT- #
# ABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General     #
# Public License for more details.                                     #
#                                                                      #
# You should have received a copy of the GNU General Public License    #
# along with SEISMIC-RNA; if not, see <https://www.gnu.org/licenses>.  #
#                                                                      #
########################################################################

==> seismic_rna-0.20.1-py3-none-any.whl: seismicrna/sim/main.py <==
from click import group

from . import clusts, ends, fastq, fold, muts, params, ref, relate, total
from ..core.arg import CMD_SIM


# Group for all sim commands
@group(CMD_SIM)
def cli():
    """ Simulate sequences, structures, and samples. """


# Add simulation commands to the CLI.
for module in (clusts, ends, fastq, fold, muts, params, ref, relate, total):
    cli.add_command(module.cli)

########################################################################
#                                                                      #
# © Copyright 2024, the Rouskin Lab.                                   #
#                                                                      #
# This file is part of SEISMIC-RNA.                                    #
#                                                                      #
# SEISMIC-RNA is free software; you can redistribute it and/or modify  #
# it under the terms of the GNU General Public License as published by #
# the Free Software Foundation; either version 3 of the License, or    #
# (at your option) any later version.                                  #
#                                                                      #
# SEISMIC-RNA is distributed in the hope that it will be useful, but   #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT- #
# ABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General     #
# Public License for more details.                                     #
#                                                                      #
# You should have received a copy of the GNU General Public License    #
# along with SEISMIC-RNA; if not, see <https://www.gnu.org/licenses>.  #
#                                                                      #
########################################################################
